How to contribute
=================

We want cf-units to be driven by the community - your contributions are
invaluable to us! This page lists the guidelines for contributors which
will help ease the process of getting your hard work accepted into cf-units,
and shared back to the world.

Getting started
---------------

1. If you've not already got one, sign up for a
   [GitHub account](https://github.com/join).
1. Fork the cf-units repository, create your new fix/feature branch, and
   start committing code.
1. Make sure you've added appropriate tests, and that *all* the tests
   pass.

Submitting changes
------------------

1. Read and sign the Contributor Licence Agreement (CLA).

   See our [governance page](http://scitools.org.uk/governance.html) for the
   CLA and what to do with it.
1. Push your branch to your fork of cf-units.
1. Submit your pull request.
1. Chillax!

If in doubt, please post in the
[cf-units Discussions space](https://github.com/SciTools/cf-units/discussions) 
and we'll be happy to help you.
